@@ -122,7 +122,7 @@ void create_application(GtkApplication *app) {
 	//create the almighty Calculator object
 	new Calculator(ignore_locale);
 
-	CALCULATOR->setExchangeRatesWarningEnabled(false);
+	CALCULATOR->setExchangeRatesWarningEnabled(!CALCULATOR->canFetch());
 
 	//load application specific preferences
 	load_preferences();
@@ -375,7 +375,8 @@ int main (int argc, char *argv[]) {
 					_putenv_s("LANGUAGE", lang.c_str());
 #	else
 					setenv("LANGUAGE", lang.c_str(), 1);
-					setenv("LC_MESSAGES", lang.c_str(), 1);
+					if(lang.find(".") == string::npos && lang.find("_") != string::npos) lang += ".utf8";
+					if(lang.find(".") != string::npos) setenv("LC_MESSAGES", lang.c_str(), 1);
 #	endif
 				}
 				break;
